@@ -502,9 +502,9 @@ class Base(Controller):
             print(update_ec2_ssh(profile))
 
         elif self.app.pargs.action=='ls':
+            from ..ext.sshconf import print_ls
             ssh_config_obj = read_ssh_config(ssh_config_path)
-            import ipdb; ipdb.set_trace()
-            print(ssh_config_obj.config())
+            print_ls(ssh_config_obj)
 
         else:
             # raise NotImplementedError()
