@@ -8,6 +8,13 @@ try:
 except OSError:
     term_width = 70
 
+
+DONGLES_TO_SKIP = [
+    'test',
+    '861579032390149', # not entirely sure why 
+]
+
+
 def urlifier(dongle, drive_time):
     """
     Turns any dongle and drive time into a cabana url
@@ -95,15 +102,17 @@ def get_selected_drives(s3, s3_resource, bucket_name, dongle_id):
 
     return latest_drive, last_complete_drive
 
-def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int, latest=False):
+def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, filter: int, latest=False):
     from tqdm import tqdm 
 
     raw_data_buckets = s3.list_objects_v2(Bucket='creationlabs-raw-data',Delimiter='/')
     dongle_ids = [x['Prefix'].split('/')[0] for x in raw_data_buckets['CommonPrefixes']]
+    if filter: dongle_ids = [ x for x in dongle_ids if x not in DONGLES_TO_SKIP]
+    else: dongle_ids = [ x for x in dongle_ids if x not in DONGLES_TO_SKIP]
 
     latest_files = []
 
-    for did in tqdm(sorted(dongle_ids[:show_n])):
+    for did in tqdm(sorted(dongle_ids)):
         latest_drive, last_complete_drive = get_selected_drives(s3, s3_resource, bucket_name, did)
         # TODO: this does not feel like the last file
         if latest:       latest_files.append(last_complete_drive)
@@ -115,7 +124,7 @@ def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int,
     
 
 def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file: str = '/home/jakub/data/asco/devices.csv',
-                        show_n: int = 25, num_segments: int = 1, filter=0):
+                        show_n: int = 50, filter=0):
     # TODO: profile
     # get all dongle ids
     import boto3 
@@ -127,9 +136,9 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file
     s3_resource = boto3.resource('s3')
 
     if target=='-1':
-        df = get_dongle_drives(s3, s3_resource, bucket_name, target, show_n, latest=True)
+        df = get_dongle_drives(s3, s3_resource, bucket_name, target, filter, latest=True)
     elif target=='0':
-        df = get_dongle_drives(s3, s3_resource, bucket_name, target, show_n)
+        df = get_dongle_drives(s3, s3_resource, bucket_name, target, filter)
     else:
         df = get_drives_df(s3_resource, bucket_name, dongle_id=target, filter=filter)
 
